@@ -91,7 +91,7 @@ download_ned_tile <- function(res="1", tileNorthing, tileWesting, raw.dir){
   
   url <- paste('ftp://rockyftp.cr.usgs.gov/vdelivery/Datasets/Staged/NED/',res,'/ArcGrid/n',tileNorthing,'w',tileWesting,'.zip',sep='')
   destdir <- paste(raw.dir,'/',res,'/',sep='')
-  curl_download(url=url, destdir=destdir)
+  download_data(url=url, destdir=destdir)
   
   return(normalizePath(paste(destdir,'n',tileNorthing,'w',tileWesting,'.zip',sep='')))
 }
